@@ -1,11 +1,10 @@
 package Net::DNS::Resolver::cygwin;
-use base Net::DNS::Resolver::Base;
 
 #
-# $Id: cygwin.pm 1068 2012-12-06 10:38:51Z willem $
+# $Id: cygwin.pm 1202 2014-05-19 08:34:16Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1068 $)[1];
+$VERSION = (qw$LastChangedRevision: 1202 $)[1];
 
 =head1 NAME
 
@@ -15,6 +14,7 @@ Net::DNS::Resolver::cygwin - Cygwin Resolver Class
 
 
 use strict;
+use base qw(Net::DNS::Resolver::Base);
 
 
 sub getregkey {
@@ -60,8 +60,8 @@ sub init {
 	$searchlist .= getregkey( $root, 'SearchList' );
 
 	# This is (probably) adequate on NT4
-	my $nt4nameservers = getregkey( $root, 'NameServer' ) || getregkey( $root, 'DhcpNameServer' );
-	my $nameservers = "";
+	my @nt4nameservers = split getregkey( $root, 'NameServer' ) || getregkey( $root, 'DhcpNameServer' );
+	my @nameservers;
 
 	#
 	# but on W2K/XP the registry layout is more advanced due to dynamically
@@ -80,7 +80,7 @@ sub init {
 				my $ns = getregkey( $regadapter, 'DNSServerAddresses' ) || '';
 				while ( length($ns) >= 4 ) {
 					my $addr = join( '.', unpack( "C4", substr( $ns, 0, 4, "" ) ) );
-					$nameservers .= " $addr";
+					push @nameservers, $addr;
 				}
 			}
 		}
@@ -103,12 +103,13 @@ sub init {
 					|| ''
 					unless !$ip || ( $ip =~ /0\.0\.0\.0/ );
 
-				$nameservers .= " $ns" if $ns;
+				push @nameservers, $ns if $ns;
 			}
 		}
 	}
 
-	$nameservers = $nt4nameservers if !$nameservers;
+	@nameservers = @nt4nameservers unless @nameservers;
+	$defaults->nameservers(@nameservers);
 
 	$defaults->{domain} = $domain if $domain;
 
@@ -133,17 +134,6 @@ sub init {
 		$defaults->{searchlist} = [@a];
 	}
 
-	if ($nameservers) {
-
-		# just in case dups were introduced...
-		my @a;
-		my %h;
-		foreach my $ns ( split( m/[\s,]+/, $nameservers ) ) {
-			push @a, $ns unless ( !$ns || $h{$ns}++ );
-		}
-		$defaults->{nameservers} = [@a];
-	}
-
 
 	$class->read_env;
 
