@@ -1,10 +1,10 @@
 package Net::DNS::ZoneFile;
 
 #
-# $Id: ZoneFile.pm 1158 2014-01-10 22:30:40Z willem $
+# $Id: ZoneFile.pm 1197 2014-04-30 11:16:08Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1158 $)[1];
+$VERSION = (qw$LastChangedRevision: 1197 $)[1];
 
 
 =head1 NAME
@@ -46,7 +46,6 @@ automatically to all subsequent records.
 use strict;
 use integer;
 use Carp;
-use File::Spec::Functions;
 
 require FileHandle;
 
@@ -80,23 +79,19 @@ by $include directives.
 
 =cut
 
-use vars qw($DIR);
-
 sub new {
 	my $self = bless {}, shift;
 	my $file = shift;
 	$self->_origin(shift);
 
 	if ( ref($file) ) {
-		$self->{name} = $self->{handle} = $file;
-		return $self if ref($file) =~ /FileHandle|GLOB|Text/;
+		$self->{filename} = $self->{handle} = $file;
+		return $self if ref($file) =~ /FileHandle|IO::File|GLOB|Text/;
 		croak 'argument not a file handle';
 	}
 
-	$file = catfile( $DIR ||= curdir(), $file ) unless file_name_is_absolute($file);
 	$self->{handle} = new FileHandle($file) or croak qq(open: "$file" $!);
-	$self->{name} = $file;
-
+	$self->{filename} = $file;
 	return $self;
 }
 
@@ -152,7 +147,7 @@ argument supplied when the object was created.
 =cut
 
 sub name {
-	return shift->{name} || '<anon>';
+	return shift->{filename} || '<anon>';
 }
 
 
@@ -166,7 +161,7 @@ Returns the number of the last line read from the current zone file.
 
 sub line {
 	my $self = shift;
-	return $self->{eof} if defined $self->{eof};
+	return $self->{eom} if defined $self->{eom};
 	return $self->{handle}->input_line_number;
 }
 
@@ -195,7 +190,10 @@ Returns the default TTL as specified by the $TTL directive.
 =cut
 
 sub ttl {
-	return shift->{ttl} || 0;
+	my $self = shift;
+	my $time = shift;
+	return $self->{ttl} || 0 unless defined $time;
+	$self->{ttl} = new Net::DNS::RR(". $time IN A")->ttl;
 }
 
 
@@ -239,12 +237,23 @@ error is encountered by the parser.
 
 =cut
 
+use vars qw($include_dir);		## dynamically scoped
+
+sub _filename {				## rebase unqualified filename
+	my $name = shift;
+	return $name unless $include_dir;
+	return $name if ref($name);	## file handle
+	require File::Spec;
+	return $name if File::Spec->file_name_is_absolute($name);
+	return File::Spec->catfile( $include_dir, $name );
+}
+
+
 sub _read {
 	my ($arg1) = @_;
 	shift unless ref($arg1) || $arg1 ne __PACKAGE__;
-	my $filename = shift;
-	local $DIR = shift;
-	my $file = new Net::DNS::ZoneFile($filename);
+	my $file = new Net::DNS::ZoneFile( _filename(shift) );
+	local $include_dir = shift;
 	my @zone;
 	eval {
 		my $rr;
@@ -260,16 +269,23 @@ sub _read {
 
 	package Net::DNS::ZoneFile::Text;
 
-	use overload ( '<>' => 'read' );
+	use overload ( '<>' => 'readline' );
 
 	sub new {
 		my $self = bless {}, shift;
 		my $data = shift;
 		$self->{data} = [split /\n/, ref($data) ? $$data : $data];
-		return $self;
+		no integer;
+		return $self unless $] < 5.006;
+
+		require IO::File;	## Plan B: ancient perl unable to overload <>
+		my $fh = IO::File->new_tmpfile() or die "Unable to create temporary file: $!";
+		while ( my $line = $self->readline ) { print $fh $line, "\n"; }
+		seek $fh, 0, 0;
+		return $fh;
 	}
 
-	sub read {
+	sub readline {
 		my $self = shift;
 		$self->{line}++;
 		return shift( @{$self->{data}} );
@@ -338,7 +354,7 @@ sub DESTROY { }				## Avoid tickling AUTOLOAD (in cleanup)
 
 	package Net::DNS::ZoneFile::Generator;
 
-	use overload ( '<>' => 'read' );
+	use overload ( '<>' => 'readline' );
 
 	sub new {
 		my $self = bless {}, shift;
@@ -358,7 +374,7 @@ sub DESTROY { }				## Avoid tickling AUTOLOAD (in cleanup)
 		return $self;
 	}
 
-	sub read {
+	sub readline {
 		my $self = shift;
 		return undef unless $self->{count}-- > 0;	# EOF
 
@@ -409,13 +425,19 @@ sub _generate {				## expand $GENERATE into input stream
 	my $handle = new Net::DNS::ZoneFile::Generator( $range, $template, $self->line );
 
 	delete $self->{latest};					# forbid empty owner field
-	my $parent = bless {%$self}, ref($self);		# save state, create link
-	$self->{link} = $parent;
-	return $self->{handle} = $handle;
+	$self->{parent} = bless {%$self}, ref($self);		# save state, create link
+	no integer;
+	return $self->{handle} = $handle unless $] < 5.006;
+
+	require IO::File;		## Plan B: ancient perl unable to overload <>
+	my $fh = IO::File->new_tmpfile() or die "Unable to create temporary file: $!";
+	while ( my $line = $handle->readline ) { print $fh $line, "\n"; }
+	seek $fh, 0, 0;
+	return $self->{handle} = $fh;
 }
 
 
-my $LEX_REGEX = q/("[^"]*")|("[^"]*)$|;[^\n]*|(^\s)|\s/;
+my $LEX_REGEX = q/("[^"]*"|"[^"]*$)|;[^\n]*|([()])|(^\s)|\s/;
 
 sub _getline {				## get line from current source
 	my $self = shift;
@@ -428,16 +450,19 @@ sub _getline {				## get line from current source
 		if (/\(/) {					# concatenate multi-line RR
 			s/\\\\/\\092/g;				# disguise escaped escape
 			s/\\"/\\034/g;				# disguise escaped quote
+			s/\\\(/\\040/g;				# disguise escaped bracket
+			s/\\\)/\\041/g;				# disguise escaped bracket
 			s/\\;/\\059/g;				# disguise escaped semicolon
 			my @token = grep defined && length, split /$LEX_REGEX/o;
-			if ( grep $_ eq '(', @token ) {
-				return $_ if grep $_ eq ')', @token;	# question user sanity
+			if ( grep( $_ eq '(', @token ) && !grep( $_ eq ')', @token ) ) {
 				while (<$fh>) {
 					s/\\\\/\\092/g;		# disguise escaped escape
 					s/\\"/\\034/g;		# disguise escaped quote
+					s/\\\(/\\040/g;		# disguise escaped bracket
+					s/\\\)/\\041/g;		# disguise escaped bracket
 					s/\\;/\\059/g;		# disguise escaped semicolon
-					substr( $_, 0, 0 ) = join ' ', @token;	  # need to handle multi-line quote
-					@token = grep defined && length, split /$LEX_REGEX/o;
+					substr( $_, 0, 0 ) = pop @token || '';	  # splice multi-line token
+					push @token, grep defined && length, split /$LEX_REGEX/o;
 					last if grep $_ eq ')', @token;
 				}
 				$_ = join ' ', @token;		# reconstitute RR string
@@ -446,25 +471,25 @@ sub _getline {				## get line from current source
 
 		return $_ unless /^\$/;				# RR string
 
-		if (/^\$ORIGIN/i) {				# directive
-			my ( undef, $origin ) = split;
+		if (/^\$ORIGIN/) {				# directive
+			my ( $keyword, $origin, @etc ) = split;
 			die '$ORIGIN incomplete' unless $origin;
 			my $context = $self->{context};
 			&$context( sub { $self->_origin($origin); } );
 
-		} elsif (/^\$INCLUDE/i) {			# directive
-			my ( undef, @argument ) = split;
+		} elsif (/^\$INCLUDE/) {			# directive
+			my ( $keyword, @argument ) = split;
 			$fh = $self->_include(@argument);
 
-		} elsif (/^\$GENERATE/i) {			# directive
-			my ( undef, $range, @template ) = split;
+		} elsif (/^\$GENERATE/) {			# directive
+			my ( $keyword, $range, @template ) = split;
 			die '$GENERATE incomplete' unless $range;
 			$fh = $self->_generate( $range, "@template\n" );
 
-		} elsif (/^\$TTL/i) {				# directive
-			my ( undef, $ttl ) = split;
+		} elsif (/^\$TTL/) {				# directive
+			my ( $keyword, $ttl, @etc ) = split;
 			die '$TTL incomplete' unless defined $ttl;
-			$self->{ttl} = new Net::DNS::RR(". $ttl IN A")->ttl;
+			$self->ttl($ttl);
 
 		} else {					# unrecognised
 			chomp;
@@ -472,11 +497,11 @@ sub _getline {				## get line from current source
 		}
 	}
 
-	$self->{eof} = $self->line;				# end of file
+	$self->{eom} = $self->line;				# end of file
 	my $ok = $fh->close;
 	die "pipe: process exit status $?" if $?;
 	die "close: $!" unless $ok;
-	my $link = $self->{link} || return undef;		# end of zone
+	my $link = $self->{parent} || return undef;		# end of zone
 	%$self = %$link;					# end $INCLUDE
 	return $self->_getline;					# resume input
 }
@@ -498,8 +523,8 @@ sub _getRR {				## get RR from current source
 
 	$rr->class( $self->{class} ||= $rr->class );		# propagate RR class
 
-	$self->{ttl} ||= $rr->type eq 'SOA' ? $rr->minimum : $rr->ttl;		  # default TTL
-	$rr->ttl( $self->{ttl} ) unless defined $rr->{ttl};
+	$self->{'ttl'} ||= $rr->type eq 'SOA' ? $rr->minimum : undef;	# default TTL
+	$rr->ttl( $self->ttl ) unless defined $rr->{'ttl'};
 
 	return $self->{latest} = $rr;
 }
@@ -507,18 +532,16 @@ sub _getRR {				## get RR from current source
 
 sub _include {				## open $INCLUDE file
 	my $self = shift;
-	my $file = shift;
+	my $file = _filename(shift);
 	my $root = shift;
 
-	$file = catfile( $DIR ||= curdir(), $file ) unless file_name_is_absolute($file);
-
 	my @discipline = ( join ':', '<', PerlIO::get_layers $self->{handle} ) if PERLIO;
 	my $handle = new FileHandle( $file, @discipline ) or croak qq(open: "$file" $!);
 
 	delete $self->{latest};					# forbid empty owner field
-	my $include = bless {%$self}, ref($self);		# save state, create link
-	@{$self}{qw(link name)} = ( $include, $file );
+	$self->{parent} = bless {%$self}, ref($self);		# save state, create link
 	$self->{context} = origin Net::DNS::Domain($root) if $root;
+	$self->{filename} = $file;
 	return $self->{handle} = $handle;
 }
 
